SelectWhenContext extension

Adds a selectWhen method on BuildContext.

on

Methods

selectWhen<T, R>(R selector(T value), {required bool when(T value)}) → R

Available on BuildContext, provided by the SelectWhenContext extension

Watches a value of type T exposed from a provider and marks this widget for rebuild based on the result of selector applied to the value, conditional on the when predicate.