SelectWhenContext extension
Adds a selectWhen method on BuildContext.
- on
Methods
-
selectWhen<
T, R> (R selector(T value), {required bool when(T value)}) → R -
Available on BuildContext, provided by the SelectWhenContext extension
Watches a value of typeTexposed from a provider and marks this widget for rebuild based on the result ofselectorapplied to the value, conditional on thewhenpredicate.